<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Grimlock_WPML_BuddyPress_Multilingual
 *
 * @author  themoasaurus
 * @since   1.0.0
 * @package grimlock-wpml/inc
 */
class Grimlock_WPML_BuddyPress_Multilingual {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_filter( 'xprofile_get_field_data', array( $this, 'translate_field_data' ), 9, 3 );
	}

	/**
	 * Translate xProfile field data
	 *
	 * @param string $value    Value saved for the field.
	 * @param int    $field_id ID of the field being displayed.
	 * @param int    $user_id  ID of the user being displayed.
	 *
	 * @return string Field value
	 */
	public function translate_field_data( $value, $field_id, $user_id ) {
		$field      = xprofile_get_field( $field_id, $user_id );
		$field_type = $field->type;

		// Only for fields with options
		if ( in_array( $field_type,
			array(
				'radio',
				'checkbox',
				'selectbox',
				'multiselectbox'
			) ) ) {
			$options = $field->get_children();
			switch ( $field_type ) {
				case 'radio':
				case 'selectbox':
					$_value = false;
					foreach ( $options as $option ) {
						if ( isset( $option->name ) && $option->name == $field->data->value ) {
							$_value = apply_filters( 'wpml_translate_single_string', $option->name, 'Buddypress Multilingual',
								$this->sanitize_option_basename( $option, $field->id ) . ' name' );
						}
					}
					if ( $_value ) {
						// Expected format is search link
						$value = str_replace( ">{$field->data->value}</a>",
							">{$_value}</a>", $value, $count );
						if ( ! $count ) {
							$value = $_value;
						}
					}
					break;

				case 'multiselectbox':
				case 'checkbox':
					foreach ( $options as $option ) {
						$_value = apply_filters( 'wpml_translate_single_string', $option->name, 'Buddypress Multilingual',
							$this->sanitize_option_basename( $option, $field->id ) . ' name' );
						// Expected format is search link
						$value = str_replace( ">{$option->name}</a>",
							">{$_value}</a>", $value, $count );
						// CSV list
						if ( ! $count && strpos( $value, $option->name ) !== false ) {
							$_ex_values = explode( ',', $value );
							if ( ! empty( $_ex_values ) ) {
								foreach ( $_ex_values as &$v ) {
									if ( trim( $v ) == $option->name ) {
										$v = $_value;
									}
								}
								$value = implode( ', ', $_ex_values );
							}
						}
					}
					break;

				default:
					break;
			}
		}

		return $value;
	}

	/**
	 * Sanitize option basename for WPML translation
	 *
	 * @param $option
	 * @param $field_id
	 *
	 * @return string
	 */
	public function sanitize_option_basename( $option, $field_id ) {
		$sanitized_string = bpml_sanitize_string_name( $option->name, 30 );
		return "profile field {$field_id} - option '{$sanitized_string}'";
	}
}